
/*

Ergänzungsskript zur Anpassung gICS Vorlage MII BroadConsent auf Version vom 27.01.2022

Betrifft MII BC Vorlage 1.6.f (NUM-CODEX VERSION) vom Juli 2021

ACHTUNG: Skript-Variablen sind nur anzupassen, sofern von der offiziell bereitgestellten Vorlage abgewichen wurde.

*/

-- betreffende Datenbank
use gics;
-- betreffende Einwilligungsdomäne
SET @DOMAINAME = 'MII';

/*
	Da Ablaufeigenschaften (*expirationProperties) von Einwilligungselementen nach Produktivsetzung standardmäßig 
	schreibgeschützt sind, muss die Ablaufdauer der zugeordneten Modul Policy `BIOMAT_Eigentum_uebertragen` 
	per SQL auf 5 Jahre gesetzt werden.
*/


/*
	Assigned Policy BIOMAT_Eigentum_uebertragen, Ablaufeigenschaften 5 Jahre ergänzen
*/


SET @POLICYNAME = 'BIOMAT_Eigentum_uebertragen';
SET @POLICYVERSION = 1000; 
SET @MODULENAME = 'BIOMAT_erheben_lagern_nutzen';
SET @MODULEVERSION = 1007; 

-- Aktualisierung der Ablaufeigenschaften

UPDATE `gics`.`module_policy` SET `EXPIRATION_PROPERTIES`='VALIDITY_PERIOD=P5Y;' 
WHERE  
    `P_NAME`=@POLICYNAME AND `P_DOMAIN_NAME`=@DOMAINAME AND `P_VERSION`=@POLICYVERSION 
    AND `M_NAME`=@MODULENAME AND `M_DOMAIN_NAME`=@DOMAINAME AND `M_VERSION`=@MODULEVERSION
;


/*
Assigned Policy MDAT_GECC083_erheben, Ablaufeigenschaften entfernen in allen Modulversionen
*/
SET @POLICYNAME = 'MDAT_GECC083_erheben';
SET @POLICYVERSION = 1000; 
SET @MODULENAME = 'Z1_GECCO83_Nutzung_NUM_CODEX';

-- Aktualisierung der Ablaufeigenschaften
UPDATE `gics`.`module_policy` SET `COMMENT`='', `EXPIRATION_PROPERTIES`='' 
WHERE  
`P_NAME`=@POLICYNAME AND `P_DOMAIN_NAME`=@DOMAINAME AND `P_VERSION`=1000 
AND `M_NAME`=@MODULENAME AND `M_DOMAIN_NAME`=@DOMAINAME;

-- Modul Z1_GECCO83_Nutzung_NUM_CODEX 1.1 anpassen

-- entfernen Policy MDAT_GECCO83_wissenschaftlich_nutzen_COVID_19_Forschung_EU_DSGVO_konform 1.0 

SET @OLD_NAME="MDAT_GECCO83_wissenschaftlich_nutzen_COVID_19_Forschung_EU_DSGVO_konform";
SET @OLD_VERSION="1000";

DELETE FROM module_policy WHERE P_DOMAIN_NAME=@DOMAINAME AND P_NAME=@OLD_NAME AND P_VERSION=@OLD_VERSION;
DELETE FROM signed_policy WHERE POLICY_DOMAIN_NAME=@DOMAINAME AND POLICY_NAME=@OLD_NAME AND POLICY_VERSION=@OLD_VERSION;
DELETE FROM policy WHERE DOMAIN_NAME=@DOMAINAME AND NAME=@OLD_NAME AND VERSION=@OLD_VERSION LIMIT 1;

-- entfernen Policy MDAT_GECCO83_wissenschaftlich_nutzen_Pandemie_Forschung_EU_DSGVO_konform 1.0 

SET @OLD_NAME="MDAT_GECCO83_wissenschaftlich_nutzen_Pandemie_Forschung_EU_DSGVO_konform";
SET @OLD_VERSION="1000";

DELETE FROM module_policy WHERE P_DOMAIN_NAME=@DOMAINAME AND P_NAME=@OLD_NAME AND P_VERSION=@OLD_VERSION;
DELETE FROM signed_policy WHERE POLICY_DOMAIN_NAME=@DOMAINAME AND POLICY_NAME=@OLD_NAME AND POLICY_VERSION=@OLD_VERSION;
DELETE FROM policy WHERE DOMAIN_NAME=@DOMAINAME AND NAME=@OLD_NAME AND VERSION=@OLD_VERSION LIMIT 1;

-- hinzufügen Policy MDAT_GECCO83_wissenschaftlich_nutzen_NUM_CODEX_EU_DSGVO_NIVEAU 1.0

set @module_name := "Z1_GECCO83_Nutzung_NUM_CODEX";
set @module_version := 1001;
set @policy_add_name := "MDAT_GECCO83_wissenschaftlich_nutzen_NUM_CODEX_EU_DSGVO_NIVEAU";
set @policy_add_version := 1000;
select @ref_policy_name := p_name from module_policy
where m_name = @module_name
and m_domain_name = @DOMAINAME
and m_version = @module_version
limit 1;
select @ref_policy_version := p_version from module_policy
where m_name = @module_name
and m_domain_name = @DOMAINAME
and m_version = @module_version
and p_name = @ref_policy_name;

-- policy bereits per template import angelegt
INSERT INTO module_policy (P_NAME, P_DOMAIN_NAME, P_VERSION, M_NAME, M_DOMAIN_NAME, M_VERSION, FHIR_ID)
VALUES (@policy_add_name, @DOMAINAME,  @policy_add_version, @module_name,  @DOMAINAME, @module_version, UUID());
-- Add policy to all existing consents and use the status of the reference policy
INSERT INTO signed_policy (STATUS, consent_date, CONSENT_VIRTUAL_PERSON_ID, CT_DOMAIN_NAME, CT_NAME, CT_VERSION, POLICY_DOMAIN_NAME, POLICY_NAME, POLICY_VERSION, FHIR_ID)
select sp.STATUS, sp.consent_date, sp.CONSENT_VIRTUAL_PERSON_ID, sp.CT_DOMAIN_NAME, sp.CT_NAME, sp.CT_VERSION, sp.POLICY_DOMAIN_NAME, @policy_add_name, @policy_add_version, UUID()
from	signed_policy sp
where sp.CT_DOMAIN_NAME = @DOMAINAME
and sp.POLICY_NAME = @ref_policy_name
and sp.POLICY_VERSION = @ref_policy_version
and concat(ct_name, '#+#+#', ct_version) in
(select concat(ct_name, '#+#+#', ct_version) from module_consent_template
where m_name = @module_name
and m_domain = @DOMAINAME
and m_version = @module_version);